Crypto class

Implemented types

Constructors

Crypto({required ICore core, Logger? logger, IKeyChain? keychain})

Properties

core → ICore
final
hashCode → int
The hash code for this object.
no setterinherited
keychain → IKeyChain
final
logger → Logger
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode({required String topic, required String encoded, CryptoDecodeOptions? opts}) → Future
override
deleteKeyPair({required String publicKey}) → Future<void>
override
deleteSymKey({required String topic}) → Future<void>
override
encode({required String topic, required Object payload, CryptoEncodeOptions? opts}) → Future<String>
override
generateKeyPair() → Future<String>
override
generateSharedKey({required String selfPublicKey, required String peerPublicKey, String? overrideTopic}) → Future<String>
override
getClientId() → Future<String>
override
getPayloadType(String encoded) → int
override
hasKeys(String tag) → bool
override
init() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setSymKey({required String symKey, String? overrideTopic}) → Future<String>
override
signJWT(String aud) → Future<String>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited