CryptoEncodingParams class

Constructors

CryptoEncodingParams({required Uint8List type, required Uint8List sealed, required Uint8List iv, Uint8List? senderPublicKey})

Properties

hashCode → int
The hash code for this object.
no setterinherited
iv → Uint8List
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sealed → Uint8List
final
senderPublicKey → Uint8List?
final
type → Uint8List
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited