CryptoEncryptParams class

Constructors

CryptoEncryptParams({required String message, required String symKey, int? type, String? iv, String? senderPublicKey})

Properties

hashCode → int
The hash code for this object.
no setterinherited
iv → String?
final
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderPublicKey → String?
final
symKey → String
final
type → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited