MessageTracker class

Implemented types

Constructors

MessageTracker({required ICore core, Logger? logger})

Properties

core → ICore
final
hashCode → int
The hash code for this object.
no setterinherited
logger → Logger
final
messages ↔ Map<String, MessageRecord>
getter/setter pairoverride-getter
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageKey → String
no setter
storagePrefix → String
final
version → String
final

Methods

del(String topic) → Future<void>
override
get(String topic) → Map<String, String>
override
has(String topic, String message) → Future<bool>
override
init() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String topic, String message) → Future<String>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited