RelayerClientMetadata class

Constructors

RelayerClientMetadata({required String protocol, required int version, required String env, String? host})

Properties

env → String
final
hashCode → int
The hash code for this object.
no setterinherited
host → String?
final
protocol → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited