SubscriberActive class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

SubscriberActive({required String id, required RelayerProtocolOptions relay, required String topic})
SubscriberActive.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
final
relay → RelayerProtocolOptions
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topic → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited