SubscriberTopicMap class

Implemented types

Constructors

SubscriberTopicMap()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topics → List<String>
no setteroverride

Methods

clear() → void
override
delete({required String topic, String? id}) → void
override
exists(String topic, String id) → bool
override
get(String topic) → List<String>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String topic, String id) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited