Engine class

Implemented types
Mixed-in types

Constructors

Engine({required ISignClient client})

Properties

client → ISignClient
final
events → EventEmitter<String>
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

approve(SessionApproveParams params) → Future<EngineApproved>
override
connect(SessionConnectParams params) → Future<EngineConnection>
override
disconnect({required String topic, ErrorResponse? reason}) → Future<void>
override
emit(SessionEmitParams params) → Future<void>
override
extend(String topic) → Future<EngineAcknowledged>
override
find(dynamic params) → List<SessionStruct>
override
getPendingSessionRequests() → List<PendingRequestStruct>
override
init() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
off(Listener<String>? listener) → void
inherited
on(String event, EventCallback callback) → Listener<String>
inherited
once(String event, EventCallback callback) → Listener<String>
inherited
pair(String uri) → Future<PairingStruct>
override
ping(String topic) → Future<void>
override
reject(SessionRejectParams params) → Future<void>
override
removeListener(String eventName, EventCallback callback) → void
inherited
request<T>(SessionRequestParams params) → Future<T>
override
respond(SessionRespondParams params) → Future<void>
override
setPendingSessionRequest(PendingRequestStruct pendingRequest) → Future<void>
toString() → String
A string representation of this object.
inherited
update(SessionUpdateParams params) → Future<EngineAcknowledged>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited