IEngine class abstract

Implementers

Constructors

IEngine()

Properties

client → ISignClient
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

approve(SessionApproveParams params) → Future<EngineApproved>
connect(SessionConnectParams params) → Future<EngineConnection>
disconnect({required String topic, ErrorResponse? reason}) → Future<void>
emit(SessionEmitParams params) → Future<void>
extend(String topic) → Future<EngineAcknowledged>
find(dynamic params) → List<SessionStruct>
getPendingSessionRequests() → List<PendingRequestStruct>
init() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pair(String uri) → Future<PairingStruct>
ping(String topic) → Future<void>
reject(SessionRejectParams params) → Future<void>
request<T>(SessionRequestParams params) → Future<T>
respond(SessionRespondParams params) → Future<void>
toString() → String
A string representation of this object.
inherited
update(SessionUpdateParams params) → Future<EngineAcknowledged>

Operators

operator ==(Object other) → bool
The equality operator.
inherited