SessionConnectParams class

Annotations
  • @JsonSerializable.new()

Constructors

SessionConnectParams({required ProposalRequiredNamespaces requiredNamespaces, String? pairingTopic, List<RelayerProtocolOptions>? relays})
SessionConnectParams.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pairingTopic → String?
final
relays → List<RelayerProtocolOptions>?
final
requiredNamespaces → ProposalRequiredNamespaces
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited