SessionUpdateParams class

Annotations
  • @JsonSerializable.new()

Constructors

SessionUpdateParams({required String topic, required SessionNamespaces namespaces})
SessionUpdateParams.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
namespaces → SessionNamespaces
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topic → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited