SessionStruct class

Annotations
  • @JsonSerializable.new()

Constructors

SessionStruct({required String topic, required RelayerProtocolOptions relay, required int expiry, required bool acknowledged, required String controller, required SessionNamespaces namespaces, ProposalRequiredNamespaces? requiredNamespaces, required SessionPublicKeyMetadata self, required SessionPublicKeyMetadata peer})
const
SessionStruct.fromJson(Map<String, dynamic> json)
factory

Properties

acknowledged → bool
final
controller → String
final
expiry → int
final
hashCode → int
The hash code for this object.
no setterinherited
namespaces → SessionNamespaces
final
peer → SessionPublicKeyMetadata
final
relay → RelayerProtocolOptions
final
requiredNamespaces → ProposalRequiredNamespaces?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
self → SessionPublicKeyMetadata
final
topic → String
final

Methods

copyWith({String? topic, RelayerProtocolOptions? relay, int? expiry, bool? acknowledged, String? controller, SessionNamespaces? namespaces, ProposalRequiredNamespaces? requiredNamespaces, SessionPublicKeyMetadata? self, SessionPublicKeyMetadata? peer}) → SessionStruct
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited